@@ -161,7 +161,12 @@ class Renderer(base.Renderer):
                             resultlist.append(res)
                     else:
                         resultlist.append(res)
-                
+            
+            if len(resultlist) == 0:
+                for res in results:
+                    if res.UID != self.context.UID():
+                        resultlist.append(res)
+            
             if limit and limit > 0:
                 resultlist = resultlist[:limit]
         return resultlist
@@ -186,6 +191,10 @@ class Renderer(base.Renderer):
                     else:
                         resultlist.append(res)
                         
+            if len(resultlist) == 0:
+                for res in results:
+                    if res.UID != self.context.UID():
+                        resultlist.append(res) 
 
             if len(resultlist) < limit:
                 limit = len(resultlist)
